@@ -1,6 +1,6 @@
 import datetime
 
-from admin_extra_buttons.api import ExtraButtonsMixin, button, confirm_action
+from admin_extra_buttons.api import ExtraButtonsMixin, button, confirm_action, link
 from adminfilters.autocomplete import AutoCompleteFilter
 from django.contrib import admin
 from django.contrib.admin import register
@@ -8,6 +8,7 @@ from django.contrib.admin.models import LogEntry
 from django.utils.translation import gettext as _
 
 from smart_admin.mixins import SmartMixin, TruncateAdminMixin
+from smart_admin.settings import check_logentry_archive_perm
 
 
 @register(LogEntry)
@@ -20,11 +21,23 @@ class LogEntryAdmin(SmartMixin, TruncateAdminMixin, ExtraButtonsMixin, admin.Mod
                    'action_time',
                    'action_flag')
     date_hierarchy = 'action_time'
+    change_form_template = "admin/logentry/change_form.html"
 
     def has_add_permission(self, request):
         return False
 
-    @button(permission="admin.archive_logentry", html_attrs={"class": "aeb-danger"})
+    def has_change_permission(self, request, obj=None):
+        return False
+
+    def has_delete_permission(self, request, obj=None):
+        return False
+
+    @link(change_list=False)
+    def edit_original(self, button):
+        button.href = button.original.get_admin_url()
+        button.title = button.original.object_repr
+
+    @button(permission=check_logentry_archive_perm, html_attrs={"class": "aeb-danger"})
     def archive(self, request):
         offset = datetime.date.today() - datetime.timedelta(days=365)
         offset_label = offset.strftime("%a, %b %d %Y")
@@ -33,12 +46,9 @@ class LogEntryAdmin(SmartMixin, TruncateAdminMixin, ExtraButtonsMixin, admin.Mod
             LogEntry.objects.filter(action_time__lt=offset).delete()
             self.message_user(request, _("Records before %s have been removed") % offset_label)
 
-        ctx = self.get_common_context(request,
-                                      original=None,
-                                      offset=offset_label,
-                                      title="Removes old data")
+        ctx = dict(original=None, offset=offset_label)
 
-        return confirm_action(self, request, _doit, "", "",
+        return confirm_action(self, request, _doit, message="", success_message="",
                               extra_context=ctx,
                               template="admin/logentry/archive.html")
 
